#[non_exhaustive]pub enum SourceTensorEncoding {
Safetensors(StoredDtype),
Gguf {
ggml_type: GgmlType,
endian: Endian,
},
RecipeOutput(StoredDtype),
}Expand description
Physical tensor encoding recorded by an admitted artifact catalog.
This remains distinct from LinearFormat, which describes the format
selected for an executable neural operator.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Safetensors(StoredDtype)
Scalar storage in a SafeTensors payload.
Gguf
One physical GGML block encoding in a GGUF shard.
Fields
RecipeOutput(StoredDtype)
Scalar tensor produced by an admitted architecture recipe before an optional executable-format lowering.
Implementations
Sourceimpl SourceTensorEncoding
impl SourceTensorEncoding
Sourcepub fn scalar_dtype(&self) -> Option<StoredDtype>
pub fn scalar_dtype(&self) -> Option<StoredDtype>
Returns the scalar dtype when this encoding is an unpacked tensor.